@@ -1,4 +1,4 @@
-#!/usr/bin/python3.5
+#!/usr/bin/python3.6
 """Autoconfigure a Django project from on a github URL.
 
 - downloads the repo
@@ -12,7 +12,7 @@ Usage:
 
 Options:
   --domain=<domain>         Domain name, eg www.mydomain.com   [default: your-username.pythonanywhere.com]
-  --python=<python-version> Python version, eg "2.7"    [default: 3.5]
+  --python=<python-version> Python version, eg "3.8"    [default: 3.6]
   --nuke                    *Irrevocably* delete any existing web app config on this domain. Irrevocably.
 """
 
@@ -37,7 +37,7 @@ def main(repo_url, domain, python_version, nuke):
     project.run_collectstatic()
     project.run_migrate()
     project.webapp.reload()
-    print(snakesay('All done!  Your site is now live at https://{domain}'.format(domain=domain)))
+    print(snakesay(f'All done!  Your site is now live at https://{domain}'))
     print()
     project.start_bash()
 
